==> lxqt-panel-1.4.0-1.src.tar.gz: lxqt-panel-1.4.0/plugin-sensors/translations/sensors_da.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="da">
<context>
    <name>LXQtSensorsConfiguration</name>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="14"/>
        <source>Sensors Settings</source>
        <translation>Indstillinger for sensorer</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="30"/>
        <source>Common</source>
        <translation>Fælles</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="42"/>
        <source>Update interval (seconds)</source>
        <translation>Opdateringsinterval (sekunder)</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="49"/>
        <source>Temperature bar width</source>
        <translation>Temperaturbjælkens bredde</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="104"/>
        <source>Temperature scale</source>
        <translation>Temperaturskala</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="110"/>
        <source>Celsius</source>
        <translation>Celsius</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="120"/>
        <source>Fahrenheit</source>
        <translation>Fahrenheit</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="132"/>
        <source>Blink status bars when the temperature is too high</source>
        <translation>Få statuslinjerne til at blinke når temperaturen er for høj</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="138"/>
        <source>Warning about high temperature</source>
        <translation>Advarsel om høj temperatur</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="152"/>
        <source>Sensors</source>
        <translation>Sensorer</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="168"/>
        <source>Detected chips:</source>
        <translation>Fundne chips:</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="175"/>
        <source>Chip features:</source>
        <translation>Chip-funktioner:</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.cpp" line="203"/>
        <source>Enabled</source>
        <translation>Aktiveret</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.cpp" line="203"/>
        <source>Label</source>
        <translation>Etiket</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.cpp" line="203"/>
        <source>Color</source>
        <translation>Farve</translation>
    </message>
</context>
</TS>

==> lxqt-panel-2.2.1-1.src.tar.gz: lxqt-panel-2.2.1/plugin-sensors/translations/sensors_da.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="da">
<context>
    <name>LXQtSensorsConfiguration</name>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="14"/>
        <source>Sensors Settings</source>
        <translation>Indstillinger for sensorer</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="30"/>
        <source>Common</source>
        <translation>Fælles</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="42"/>
        <source>Update interval (seconds)</source>
        <translation>Genopfriskningsinterval (sekunder)</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="74"/>
        <source>Temperature bar width</source>
        <translation>Temperaturbjælkens bredde</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="110"/>
        <source>Temperature scale</source>
        <translation>Temperaturskala</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="116"/>
        <source>Celsius</source>
        <translation>Celsius</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="126"/>
        <source>Fahrenheit</source>
        <translation>Fahrenheit</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="91"/>
        <source>Blink status bars when the temperature is too high</source>
        <translation>Få statuslinjerne til at blinke når temperaturen er for høj</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="97"/>
        <source>Warning about high temperature</source>
        <translation>Advarsel om høj temperatur</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="152"/>
        <source>Sensors</source>
        <translation>Sensorer</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="158"/>
        <source>Detected chips:</source>
        <translation>Fundne chips:</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.ui" line="175"/>
        <source>Chip features:</source>
        <translation>Chip-funktioner:</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.cpp" line="203"/>
        <source>Enabled</source>
        <translation>Aktiveret</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.cpp" line="203"/>
        <source>Label</source>
        <translation>Etiket</translation>
    </message>
    <message>
        <location filename="../lxqtsensorsconfiguration.cpp" line="203"/>
        <source>Color</source>
        <translation>Farve</translation>
    </message>
</context>
</TS>
